==> core-react-0.8.0.tgz: package/es/Tooltip/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Popover from '../Popover';


var Tooltip = function Tooltip(props) {
  var children = props.children,
      className = props.className,
      title = props.title,
      other = _objectWithoutProperties(props, ["children", "className", "title"]);

  return React.createElement(Popover, _extends({
    className: cx("".concat("waui", "-tooltip__popover"), className),
    content: title
  }, other), children);
};

Tooltip.defaultProps = {
  triggerMode: 'hover',
  direction: 'up',
  align: 'middle'
};
Tooltip.propTypes = {
  className: PropTypes.string,
  children: PropTypes.element.isRequired,

  /** The title of tooltips */
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /** The mode of triggering tooltips */
  triggerMode: PropTypes.oneOf(['hover', 'click']),

  /** The direction of tooltips */
  direction: PropTypes.oneOf(['up', 'down', 'left', 'right']),

  /** The alignment of tooltips */
  align: PropTypes.oneOf(['top', 'right', 'bottom', 'left', 'middle'])
};
export default Tooltip;

==> core-react-0.8.2.tgz: package/es/Tooltip/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Popover from '../Popover';


var Tooltip = function Tooltip(props) {
  var children = props.children,
      className = props.className,
      title = props.title,
      other = _objectWithoutProperties(props, ["children", "className", "title"]);

  return (/*#__PURE__*/React.createElement(Popover, _extends({
      className: cx("".concat("waui", "-tooltip__popover"), className),
      content: title
    }, other), children)
  );
};

Tooltip.defaultProps = {
  triggerMode: 'hover',
  direction: 'up',
  align: 'middle'
};
Tooltip.propTypes = {
  className: PropTypes.string,
  children: PropTypes.element.isRequired,

  /** The title of tooltips */
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /** The mode of triggering tooltips */
  triggerMode: PropTypes.oneOf(['hover', 'click']),

  /** The direction of tooltips */
  direction: PropTypes.oneOf(['up', 'down', 'left', 'right']),

  /** The alignment of tooltips */
  align: PropTypes.oneOf(['top', 'right', 'bottom', 'left', 'middle'])
};
export default Tooltip;
